==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebNavDrawerHeaderItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerHeaderItemDescription } from "./WebNavDrawerHeaderItemDescription";
/**
 * @hidden
 */
var WebNavDrawerHeaderItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebNavDrawerHeaderItemDescriptionMetadata, _super);
    function WebNavDrawerHeaderItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavDrawerHeaderItemDescriptionMetadata.b = function (a) {
        if (WebNavDrawerHeaderItemDescriptionMetadata.a == null) {
            WebNavDrawerHeaderItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavDrawerHeaderItemDescriptionMetadata.c(WebNavDrawerHeaderItemDescriptionMetadata.a);
        }
        if (a.g(WebNavDrawerHeaderItemDescriptionMetadata.a)) {
            return;
        }
        a.s(WebNavDrawerHeaderItemDescriptionMetadata.a);
    };
    WebNavDrawerHeaderItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NavDrawerHeaderItem");
    };
    WebNavDrawerHeaderItemDescriptionMetadata.d = function (a) {
        WebNavDrawerHeaderItemDescriptionMetadata.b(a);
        a.u("WebNavDrawerHeaderItem", function () { return new WebNavDrawerHeaderItemDescription(); });
        a.t("WebNavDrawerHeaderItem", WebNavDrawerHeaderItemDescriptionMetadata.a);
    };
    WebNavDrawerHeaderItemDescriptionMetadata.$t = markType(WebNavDrawerHeaderItemDescriptionMetadata, 'WebNavDrawerHeaderItemDescriptionMetadata');
    WebNavDrawerHeaderItemDescriptionMetadata.a = null;
    return WebNavDrawerHeaderItemDescriptionMetadata;
}(Base));
export { WebNavDrawerHeaderItemDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebNavDrawerHeaderItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavDrawerHeaderItemDescription } from "./WebNavDrawerHeaderItemDescription";
/**
 * @hidden
 */
var WebNavDrawerHeaderItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebNavDrawerHeaderItemDescriptionMetadata, _super);
    function WebNavDrawerHeaderItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebNavDrawerHeaderItemDescriptionMetadata.b = function (a) {
        if (WebNavDrawerHeaderItemDescriptionMetadata.a == null) {
            WebNavDrawerHeaderItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebNavDrawerHeaderItemDescriptionMetadata.c(WebNavDrawerHeaderItemDescriptionMetadata.a);
        }
        if (a.j(WebNavDrawerHeaderItemDescriptionMetadata.a)) {
            return;
        }
        a.y(WebNavDrawerHeaderItemDescriptionMetadata.a);
    };
    WebNavDrawerHeaderItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:NavDrawerHeaderItem");
        a.item("__tagNameWC", "String:igc-nav-drawer-header-item");
    };
    WebNavDrawerHeaderItemDescriptionMetadata.d = function (a) {
        WebNavDrawerHeaderItemDescriptionMetadata.b(a);
        a.aa("WebNavDrawerHeaderItem", function () { return new WebNavDrawerHeaderItemDescription(); });
        a.z("WebNavDrawerHeaderItem", WebNavDrawerHeaderItemDescriptionMetadata.a);
    };
    WebNavDrawerHeaderItemDescriptionMetadata.$t = markType(WebNavDrawerHeaderItemDescriptionMetadata, 'WebNavDrawerHeaderItemDescriptionMetadata');
    WebNavDrawerHeaderItemDescriptionMetadata.a = null;
    return WebNavDrawerHeaderItemDescriptionMetadata;
}(Base));
export { WebNavDrawerHeaderItemDescriptionMetadata };
